@@ -17,13 +17,9 @@ or do {
 };
 
 # Constants
-sub true  () { !!1 }
-sub false () { !!0 }
-sub ro    () { 'ro' }
-sub rw    () { 'rw' }
-sub rwp   () { 'rwp' }
-sub lazy  () { 'lazy' }
-sub bare  () { 'bare' }
+sub true  () { !!1 }    sub false () { !!0 }
+sub ro    () { 'ro' }   sub rw    () { 'rw' }   sub rwp   () { 'rwp' }
+sub lazy  () { 'lazy' } sub bare  () { 'bare' }
 
 # More complicated constants
 BEGIN {
@@ -96,33 +92,41 @@ sub _is_compiling {
 
 sub import {
     my $me = shift;
-    my %arg = map { lc($_) => true } @_;
+    my %arg = map +( lc($_) => true ), @_;
     my ( $caller, $file ) = caller;
 
     if( _is_compiling() ) {
         require Mite::Project;
-        Mite::Project->default->inject_mite_functions(
-            package => $caller,
-            file    => $file,
-            arg     => \%arg,
-            shim    => $me,
+        'Mite::Project'->default->inject_mite_functions(
+            'package' => $caller,
+            'file'    => $file,
+            'arg'     => \%arg,
+            'shim'    => $me,
         );
     }
     else {
-        # Changes to this filename must be coordinated with Mite::Compiled
-        my $mite_file = $file . ".mite.pm";
-        if( !-e $mite_file ) {
-            croak "Compiled Mite file ($mite_file) for $file is missing";
+        # Try to determine original filename for caller, minus libdir.
+        # This would normally be in %INC but caller hasn't finished loading yet.
+        require File::Spec;
+        my $orig = $file;
+        for my $base ( @INC ) {
+            $base eq substr $file, 0, length $base
+            and -f File::Spec->catfile( $base, substr $file, 1 + length $base )
+            and $orig = File::Spec->abs2rel( $file, $base )
+            and last;
         }
 
-        {
-            local @INC = ('.', @INC);
-            require $mite_file;
+        # Changes to this filename must be coordinated with Mite::Compiled
+        my $mite_file = $orig . '.mite.pm';
+        local $@;
+        if ( not eval { require $mite_file; 1 } ) {
+            my $e = $@;
+            croak "Compiled Mite file ($mite_file) for $file is missing or an error occurred loading it: $e";
         }
     }
 
-    warnings->import;
-    strict->import;
+    'warnings'->import;
+    'strict'->import;
     'namespace::autoclean'->import( -cleanee => $caller )
         if _HAS_AUTOCLEAN && !$arg{'-unclean'};
 }
